# Underwater Acoustic Analysis Toolbox
Welcome to the Underwater Acoustic Analysis toolbox for python.
This contains implementations of some analysis methods for underwater acoustics, with a focus on monitoring of noise for environmental impact.

- **Documentation**: https://underwater-acoustic-analysis.readthedocs.io
- **Source code**: https://github.com/CarlAndersson/underwater-acoustic-analysis

## Issues?
It you have issues, feel free to open an issue on the [issue tracker](https://github.com/CarlAndersson/underwater-acoustic-analysis/issues).
You can use this not only for bug reports, but also for general questions about how to use the code.

## Installation
This project is not yet available on PyPI, but you can install it directly from the github repository.
```
pip install "uwacan @ git+https://github.com/CarlAndersson/underwater-acoustic-analysis@main"
```
```
uv add "uwacan @ git+https://github.com/CarlAndersson/underwater-acoustic-analysis" --branch main
```
For other python enrivonment managers, refer to their specific documentation on VCS or git support.
